flask-oidc-ext
==============

`OpenID Connect`_ support for `Flask`_. |image| |image1| |Documentation Status| |image2|

.. _OpenID Connect: https://openid.net/connect/
.. _Flask: http://flask.pocoo.org/
.. _Google+ Login: https://developers.google.com/accounts/docs/OAuth2Login
.. _Ipsilon: https://ipsilon-project.org/

.. |image| image:: https://img.shields.io/pypi/v/flask-oidc-ext.svg?style=flat
   :target: https://pypi.python.org/pypi/flask-oidc-ext
.. |image1| image:: https://img.shields.io/pypi/dm/flask-oidc-ext.svg?style=flat
   :target: https://pypi.python.org/pypi/flask-oidc-ext
.. |Documentation Status| image:: https://readthedocs.org/projects/flask-oidc/badge/?version=latest
   :target: http://flask-oidc.readthedocs.io/en/latest/?badge=latest
.. |image2| image:: https://img.shields.io/travis/puiterwijk/flask-oidc.svg?style=flat
   :target: https://travis-ci.org/puiterwijk/flask-oidc

This library should work with any standards compliant OpenID Connect
provider.

It has been tested with:

* `Google+ Login <https://developers.google.com/accounts/docs/OAuth2Login>`_
* `Ipsilon <https://ipsilon-project.org/>`_
* `MojeID <https://mojeid.cz>`_

--------------

Project status
**************

This project comes as is, it is no longer being maintained as it does not need to at it's core.
Any necessary updates will be reviewed and released.

--------------

Extension list
**************

-  Added extra header option to requests ``OIDC_EXTRA_REQUEST_HEADERS``.
   This adds the ability to add a ``Host: <issuer>`` header in
   environments where the issuer is no the same DNS as where the request
   is sent to. E.g ``localhost`` vs ``127.0.0.1``.
- Token caching added: https://github.com/svintit/flask-oidc-ext/pull/9
- Better error handling: https://github.com/svintit/flask-oidc-ext/pull/5
- Useful helper functions added `get_token` and for clearing specific tokens

